jupyter_packaging: Jupyter Packaging Utilities
==============================================

Description
-----------

Jupyter Packaging Utilities

License
-------

BSD

Upstream Contact
----------------

https://pypi.org/project/jupyter-packaging/

